@@ -2,7 +2,7 @@
  * ProFTPD - FTP server daemon
  * Copyright (c) 1997, 1998 Public Flood Software
  * Copyright (c) 1999, 2000 MacGyver aka Habeeb J. Dihu <macgyver@tos.net>
- * Copyright (c) 2001, 2002, 2003 The ProFTPD Project team
+ * Copyright (c) 2001-2007 The ProFTPD Project team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
 
 /* ProFTPD module definitions.
  *
- * $Id: modules.h,v 1.40 2004/07/20 17:39:59 castaglia Exp $
+ * $Id: modules.h,v 1.48 2007/01/19 21:59:44 castaglia Exp $
  */
 
 #ifndef PR_MODULES_H
@@ -43,43 +43,19 @@ struct modret_struc {
   void	 *data;				/* add'l data -- undefined */
 };
 
-/* Possible return codes for auth handlers
- */
-
-/* Account authenticated by RFC2228 security data exchange */
-#define PR_AUTH_RFC2228_OK		2
-
-/* Account authenticated normally */
-#define PR_AUTH_OK			0
-
-/* Error occurred in auth handler */
-#define PR_AUTH_ERROR			-1
-
-/* Account does not exist */
-#define PR_AUTH_NOPWD			-2
-
-/* Password mismatch */
-#define PR_AUTH_BADPWD			-3
-
-/* Password hasn't been changed recently enough */
-#define PR_AUTH_AGEPWD			-4
-
-/* Account has been disabled */
-#define PR_AUTH_DISABLEDPWD		-5
-
 /* The following macros are for creating basic modret_t, and can
  * only be used inside of module handlers
  */
 
 #define MODRET				static modret_t*
-#define HANDLED(cmd)			mod_create_ret((cmd),\
+#define PR_HANDLED(cmd)			mod_create_ret((cmd),\
 					0,NULL,NULL)
-#define DECLINED(cmd)			(modret_t*)NULL
-#define ERROR(cmd)			mod_create_ret((cmd),\
+#define PR_DECLINED(cmd)		(modret_t*)NULL
+#define PR_ERROR(cmd)			mod_create_ret((cmd),\
 					1,NULL,NULL)
-#define ERROR_MSG(cmd,n,m)		mod_create_ret((cmd),\
+#define PR_ERROR_MSG(cmd,n,m)		mod_create_ret((cmd),\
 					1,(n),(m))
-#define ERROR_INT(cmd,n)		mod_create_error((cmd),(n))
+#define PR_ERROR_INT(cmd,n)		mod_create_error((cmd),(n))
 
 #define MODRET_ISDECLINED(x)		((x) == NULL)
 #define MODRET_ISHANDLED(x)		((x) && !(x)->mr_error)
@@ -91,20 +67,6 @@ struct modret_struc {
 #define MODRET_ERRMSG(x)		((x) ? (x)->mr_message : NULL)
 #define MODRET_HASDATA(x)		((x) ? ((x)->data ? TRUE : FALSE) : FALSE)
 
-/* private data structure returned by mod_priv* */
-
-struct privdata {
-  char *tag;
-  union {
-    void *ptr_val;
-    int int_val;
-    long long_val;
-    char *str_val;
-  } value;
-
-  module *m;
-};
-
 typedef struct {
   char *directive;
   modret_t *(*handler)(cmd_rec*);
@@ -124,9 +86,10 @@ typedef struct {
 #define CL_READ				(1 << 3) /* File reading commands (RETR) */
 #define CL_WRITE			(1 << 4) /* Writing commands (STOR, MKD, etc) */
 #define CL_MISC				(1 << 5) /* Miscellaneous (RNFR/RNTO, SITE, etc) */
+#define CL_SEC				(1 << 6) /* RFC2228 Security commands */
 
 #define CL_ALL				(CL_AUTH|CL_INFO|CL_DIRS|CL_READ| \
-					CL_WRITE|CL_MISC)
+					CL_WRITE|CL_MISC|CL_SEC)
 
 /* Command handler types for command table */
 #define PRE_CMD				1
@@ -226,36 +189,12 @@ extern int (*cmd_auth_chk)(cmd_rec *);
 modret_t *mod_create_ret(cmd_rec *, unsigned char, char *, char *);
 modret_t *mod_create_error(cmd_rec *, int);
 modret_t *mod_create_data(cmd_rec *, void *);
-privdata_t *mod_privdata_alloc(cmd_rec *, char *, int);
-privdata_t *mod_privdata_find(cmd_rec *, char *, module *);
 
 /* Implemented in main.c */
-void pr_cmd_dispatch(cmd_rec *);
+int pr_cmd_dispatch(cmd_rec *);
 
 /* Implemented in mod_core.c */
-int core_display_file(const char *, const char *, const char *);
 int core_chgrp(cmd_rec *, char *, uid_t, gid_t);
 int core_chmod(cmd_rec *, char *, mode_t);
 
-/* Implemented in auth.c */
-void auth_setpwent(pool *);
-void auth_endpwent(pool *);
-void auth_setgrent(pool *);
-void auth_endgrent(pool *);
-struct passwd *auth_getpwent(pool *);
-struct group *auth_getgrent(pool *);
-struct passwd *auth_getpwnam(pool *, const char *);
-struct passwd *auth_getpwuid(pool *, uid_t);
-struct group *auth_getgrnam(pool *, const char *);
-struct group *auth_getgrgid(pool *, gid_t);
-int auth_authenticate(pool *, const char *, const char *);
-int auth_check(pool *, const char *, const char *, const char *);
-const char *auth_uid_name(pool *, uid_t);
-const char *auth_gid_name(pool *, gid_t);
-uid_t auth_name_uid(pool *, const char *);
-gid_t auth_name_gid(pool *, const char *);
-int auth_getgroups(pool *, const char *, array_header **, array_header **);
-
-int set_groups(pool *, gid_t, array_header *);
-
 #endif /* PR_MODULES_H */
